# proto-inspect

[![Build Status](https://travis-ci.org/mumbleskates/proto-inspect.svg?branch=master)](https://travis-ci.org/mumbleskates/proto-inspect)
[![Coverage Status](https://coveralls.io/repos/github/mumbleskates/proto-inspect/badge.svg?branch=master)](https://coveralls.io/github/mumbleskates/proto-inspect?branch=master)

Tools for decoding, inspecting, modifying, and re-serializing protobuf data for the REPL.
